==> myfaces-tobago-2.5.3-dist.zip: org/apache/myfaces/tobago/internal/taglib/declaration/IsOmit.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.myfaces.tobago.internal.taglib.declaration;

import org.apache.myfaces.tobago.apt.annotation.TagAttribute;
import org.apache.myfaces.tobago.apt.annotation.UIComponentTagAttribute;

public interface IsOmit {
  /**
   * Flag indicating that the action of this element, will not be executed from client side (e. g. when the user clicks
   * a button. When setting this value to true, the action will not be executed by the Tobago, but it can executed by
   * JavaScript. This attribute is useful, when you want to add JavaScript event handlers to commands manually. In this
   * case you usually don't want a submit with a full reload of the page.
   */
  @TagAttribute()
  @UIComponentTagAttribute(type = "boolean", defaultValue = "false")
  void setOmit(String omit);
}

==> myfaces-tobago-5.12.0-dist.zip: org/apache/myfaces/tobago/internal/taglib/declaration/IsOmit.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.myfaces.tobago.internal.taglib.declaration;

import org.apache.myfaces.tobago.apt.annotation.TagAttribute;
import org.apache.myfaces.tobago.apt.annotation.UIComponentTagAttribute;

public interface IsOmit {
  /**
   * Flag indicating that the action of this element, will not be executed from client side
   * (e. g. when the user clicks a button.
   * When setting this value to true, the action will not be executed by the Tobago, but it can executed
   * by JavaScript.
   * This attribute is useful, when you want to add JavaScript event handlers to commands manually.
   * In this case you usually don't want a submit with a full reload of the page.
   */
  @TagAttribute()
  @UIComponentTagAttribute(type = "boolean", defaultValue = "false")
  void setOmit(String omit);
}
